import {
  CurrencyCode,
  SellingPlanAllocationConnection,
} from '../../../graphql/types/types';
import {getUnitPriceMeasurement} from '../../../utilities/tests/unitPriceMeasurement';

const priceV2 = {
  amount: '9.99',
  currencyCode: CurrencyCode.Cad,
};

export const VARIANTS = {
  edges: [
    {
      node: {
        id: '1',
        title: 'Black / Small',
        selectedOptions: [
          {
            name: 'Color',
            value: 'Black',
          },
          {
            name: 'Size',
            value: 'Small',
          },
        ],
        availableForSale: true,
        unitPrice: priceV2,
        unitPriceMeasurement: getUnitPriceMeasurement(),
        priceV2,
        metafields: {edges: []},
      },
    },
    {
      node: {
        id: '2',
        title: 'Black / Large',
        selectedOptions: [
          {
            name: 'Color',
            value: 'Black',
          },
          {
            name: 'Size',
            value: 'Large',
          },
        ],
        availableForSale: true,
        unitPrice: priceV2,
        unitPriceMeasurement: getUnitPriceMeasurement(),
        priceV2,
        metafields: {edges: []},
      },
    },
    {
      node: {
        id: '3',
        title: 'White / Small',
        selectedOptions: [
          {
            name: 'Color',
            value: 'White',
          },
          {
            name: 'Size',
            value: 'Small',
          },
        ],
        availableForSale: true,
        unitPrice: priceV2,
        unitPriceMeasurement: getUnitPriceMeasurement(),
        priceV2,
        metafields: {edges: []},
      },
    },
    {
      node: {
        id: '4',
        title: 'White / Large',
        selectedOptions: [
          {
            name: 'Color',
            value: 'White',
          },
          {
            name: 'Size',
            value: 'Large',
          },
        ],
        availableForSale: false,
        unitPrice: priceV2,
        unitPriceMeasurement: getUnitPriceMeasurement(),
        priceV2,
        metafields: {edges: []},
      },
    },
  ],
};

export const SELLING_PLAN_GROUPS_CONNECTION = {
  edges: [
    {
      node: {
        id: 'abc',
        name: 'Subscribe & Save',
        options: [
          {
            name: 'Deliver every',
            values: ['week', '2 weeks'],
          },
        ],
        sellingPlans: {
          pageInfo: {
            hasNextPage: false,
            hasPreviousPage: false,
          },
          edges: [
            {
              cursor: '1234',
              node: {
                id: 'abc',
                name: 'Deliver every week',
                options: [
                  {
                    name: 'Deliver every',
                    value: 'week',
                  },
                ],
                priceAdjustments: [],
                recurringDeliveries: false,
              },
            },
            {
              cursor: '5678',
              node: {
                id: 'def',
                name: 'Deliver every 2 weeks',
                options: [
                  {
                    name: 'Deliver every',
                    value: '2 weeks',
                  },
                ],
                priceAdjustments: [],
                recurringDeliveries: false,
              },
            },
          ],
        },
      },
    },
  ],
};

export const VARIANTS_WITH_SELLING_PLANS = {
  edges: (VARIANTS.edges ?? []).map((edge) => {
    const sellingPlanAllocations: SellingPlanAllocationConnection = {
      pageInfo: {
        hasNextPage: false,
        hasPreviousPage: false,
      },
      edges: [
        {
          cursor: '1234',
          node: {
            sellingPlan: {
              id: 'abc',
              name: 'Deliver every week',
              options: [
                {
                  name: 'Deliver every',
                  value: 'week',
                },
              ],
              priceAdjustments: [],
              recurringDeliveries: false,
            },
            priceAdjustments: [
              {
                price: {
                  amount: '10',
                  currencyCode: CurrencyCode.Usd,
                },
                compareAtPrice: {
                  amount: '10',
                  currencyCode: CurrencyCode.Usd,
                },
                perDeliveryPrice: {
                  amount: '10',
                  currencyCode: CurrencyCode.Usd,
                },
                unitPrice: {
                  amount: '10',
                  currencyCode: CurrencyCode.Usd,
                },
              },
            ],
          },
        },
        {
          cursor: '4567',
          node: {
            sellingPlan: {
              id: 'def',
              name: 'Deliver every 2 weeks',
              options: [
                {
                  name: 'Deliver every',
                  value: '2 weeks',
                },
              ],
              priceAdjustments: [],
              recurringDeliveries: false,
            },
            priceAdjustments: [
              {
                price: {
                  amount: '9',
                  currencyCode: CurrencyCode.Usd,
                },
                compareAtPrice: {
                  amount: '9',
                  currencyCode: CurrencyCode.Usd,
                },
                perDeliveryPrice: {
                  amount: '9',
                  currencyCode: CurrencyCode.Usd,
                },
                unitPrice: {
                  amount: '9',
                  currencyCode: CurrencyCode.Usd,
                },
              },
            ],
          },
        },
      ],
    };

    return {
      node: {
        ...edge.node,
        sellingPlanAllocations,
      },
    };
  }),
};
